@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/local/bin/perl
 #
 # A small script to strip out any "illegal" PGP code to make sure it is
 # safe for International export.
@@ -6,18 +6,14 @@
 $word = shift;
 $illegal = 0;
 $count = 0;
-while (<>)
-{
-	if (/^#if/)
-	{
+while (<>) {
+	if (/^#if/) {
 		if (/${word}/) { $illegal = 1; }
 		if ($illegal) { $count++; }
 	}
-	elsif ($illegal && /^#endif/)
-	{
+	elsif ($illegal && /^#endif/) {
 		$count--;
-		if ($count == 0)
-		{
+		if ($count == 0) {
 			$illegal = 0;
 			next;
 		}
